<?php
require_once '../db/db.php';
session_start();

if (!isset($_SESSION['user_id'])) {
  die("Acesso negado.");
}

$clienteId = isset($_POST['cliente_id']) ? (int) $_POST['cliente_id'] : 0;
$meses = isset($_POST['quantidade']) ? (int) $_POST['quantidade'] : 0;
$produtoId = $_POST['produto_id'] ?? null;
$startTime = $_POST['start_time'] ?? null;
$name = $_POST['name'] ?? null;

$revendaId = $_SESSION['user_id'];

// Se startTime estiver vazio ou inválido, define como a hora atual em formato ISO 8601
if (!$startTime) {
  $startTime = (new DateTime())->format('Y-m-d\TH:i:s.000\Z');
}

if ($meses < 1 || !$clienteId || !$produtoId || !$startTime || !$name) {
  echo "<pre>Dados incompletos:\n";
  print_r([
    'cliente_id' => $clienteId,
    'quantidade' => $meses,
    'produto_id' => $produtoId,
    'start_time' => $startTime,
    'name' => $name
  ]);
  echo "</pre>";
  exit;
}

// Verifica os créditos do revendedor
$stmt = $pdo->prepare("SELECT credits, username FROM reg_users WHERE id = ?");
$stmt->execute([$revendaId]);
$revenda = $stmt->fetch(PDO::FETCH_ASSOC);
$revendaUsername = $revenda['username'] ?? 'desconhecido';

if (!$revenda || $revenda['credits'] < $meses) {
  header("Location: /panel/dashboard.php?toast=erro&msg=Créditos insuficientes");
  exit;
}

// Calcula nova data de validade
$startDate = new DateTime($startTime);
$startDate->modify("+{$meses} months");
$newEndTime = $startDate->format('Y-m-d\TH:i:s.000\Z');

$payload = [
  'productId'  => $produtoId,
  'endTime'    => $newEndTime,
  'startTime'  => $startTime,
  'serviceTag' => 'Renovado via Painel FastTV',
  'status'     => 1,
  'exField1'   => (string)$revendaId,
  'exField2'   => $revendaUsername,
];

// LOG PARA DEBUG
file_put_contents('/tmp/renovar_payload.log', json_encode([
  'url' => "https://api1.fasttv.space/api/v1in/user/{$clienteId}?t=a4b9e4ad1de7e3511b5d83ef66ea905ccac0e1163b5089b7",
  'payload' => $payload
], JSON_PRETTY_PRINT));

$url = "https://api1.fasttv.space/api/v1in/user/{$clienteId}?t=a4b9e4ad1de7e3511b5d83ef66ea905ccac0e1163b5089b7";
$ch = curl_init($url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload));
curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/json']);
$response = curl_exec($ch);
$httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
curl_close($ch);

if ($httpCode === 200) {
  $stmt = $pdo->prepare("UPDATE reg_users SET credits = credits - ? WHERE id = ?");
  $stmt->execute([$meses, $revendaId]);
  header("Location: /panel/dashboard.php?toast=sucesso&msg=Cliente renovado com sucesso!");
  exit;
} else {
  echo "<pre>Erro na API:\n";
  echo "URL: {$url}\n";
  echo "Payload:\n" . json_encode($payload, JSON_PRETTY_PRINT) . "\n";
  echo "Response:\n" . htmlspecialchars($response) . "\n";
  echo "HTTP Code: {$httpCode}";
  echo "</pre>";
  exit;
}