<?php


session_start();

require_once 'db/db.php';

// Dados do usuário logado
$username = $_SESSION['user'];
$userId = $_SESSION['user_id'];

// Busca créditos do usuário
$stmt = $pdo->prepare("SELECT credits FROM reg_users WHERE id = ?");
$stmt->execute([$userId]);
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$creditos = $row['credits'] ?? 0;

// Busca revendas
$stmt = $pdo->prepare("SELECT id, username, credits, status FROM reg_users WHERE owner_id = ?");
$stmt->execute([$userId]);
$revendas = $stmt->fetchAll(PDO::FETCH_ASSOC);





// Busca com paginação
$search = $_GET['search'] ?? '';
$limit = 10; // registros por página
$page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
$offset = ($page - 1) * $limit;

// Query base + busca se necessário
$sql = "SELECT id, username, credits, status FROM reg_users WHERE owner_id = ?";
$params = [$userId];

if (!empty($search)) {
    $sql .= " AND username LIKE ?";
    $params[] = "%$search%";
}

$sql .= " LIMIT $limit OFFSET $offset";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$revendas = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Contagem total para paginação
$sqlCount = "SELECT COUNT(*) FROM reg_users WHERE owner_id = ?";
$countParams = [$userId];

if (!empty($search)) {
    $sqlCount .= " AND username LIKE ?";
    $countParams[] = "%$search%";
}

$stmt = $pdo->prepare($sqlCount);
$stmt->execute($countParams);
$total = $stmt->fetchColumn();
$totalPages = ceil($total / $limit);



?>


<?php include 'includes/header.php'; ?>
<?php include 'includes/sidebar.php'; ?>
<?php include 'includes/navbar.php'; ?>

<div class="content-wrapper">
  <div class="container-xxl flex-grow-1 container-p-y">
    <div class="card">
      <h5 class="card-header">Meus Revendas</h5>
      <div class="table-responsive text-nowrap">
	  
<div class="m-3">
  <input type="text" id="searchInput" class="form-control" placeholder="Digite para buscar o usuario...">
</div>

        <table class="table table-striped">
          <thead>
            <tr>
              <th>Usuário</th>
              <th>Créditos</th>
              <th>Status</th>
              <th>Ações</th>
            </tr>
          </thead>
          <tbody class="table-border-bottom-0">
            <?php foreach ($revendas as $revenda): ?>
  <tr>
    <td><strong><?= htmlspecialchars($revenda['username']) ?></strong></td>
    <td><?= $revenda['credits'] ?></td>
    <td>
      <?php if ($revenda['status'] == 1): ?>
        <span class="badge bg-success">Ativo</span>
      <?php else: ?>
        <span class="badge bg-danger">Bloqueado</span>
      <?php endif; ?>
    </td>
    <td>
      <div class="dropdown">
        <button type="button" class="btn p-0 dropdown-toggle hide-arrow" data-bs-toggle="dropdown">
          <i class="bx bx-dots-vertical-rounded"></i>
        </button>
        <div class="dropdown-menu">
          <a class="dropdown-item" href="#" data-id="<?= $revenda['id'] ?>" data-nome="<?= htmlspecialchars($revenda['username']) ?>" data-bs-toggle="modal" data-bs-target="#modalAddCredito">
            <i class="bx bx-plus-circle me-1"></i> Add Créditos
          </a>
          <a class="dropdown-item" href="#" data-id="<?= $revenda['id'] ?>" data-nome="<?= htmlspecialchars($revenda['username']) ?>" data-bs-toggle="modal" data-bs-target="#modalRemCredito">
            <i class="bx bx-minus-circle me-1"></i> Rem Créditos
          </a>
     <!--   <a class="dropdown-item" href="javascript:void(0);" data-id="<?= $revenda['id'] ?>">
            <i class="bx bx-edit-alt me-1"></i> Editar
          </a> -->
          <?php if ($revenda['status'] == 1): ?>
            <a class="dropdown-item" href="#" data-id="<?= $revenda['id'] ?>" data-status="0" data-bs-toggle="modal" data-bs-target="#modalStatus">
              <i class="bx bx-lock-alt me-1"></i> Bloquear
            </a>
          <?php else: ?>
            <a class="dropdown-item" href="#" data-id="<?= $revenda['id'] ?>" data-status="1" data-bs-toggle="modal" data-bs-target="#modalStatus">
              <i class="bx bx-lock-open-alt me-1"></i> Desbloquear
            </a>
          <?php endif; ?>
          <a class="dropdown-item text-danger" href="#" data-id="<?= $revenda['id'] ?>" data-nome="<?= htmlspecialchars($revenda['username']) ?>" data-bs-toggle="modal" data-bs-target="#modalExcluir">
            <i class="bx bx-trash me-1"></i> Excluir
          </a>
        </div>
      </div>
    </td>
  </tr>
<?php endforeach; ?>

          </tbody>
        </table>
      </div>
	  
	  <nav class="mt-3">
  <ul class="pagination justify-content-center">
    <?php for ($i = 1; $i <= $totalPages; $i++): ?>
      <li class="page-item <?= $i == $page ? 'active' : '' ?>">
        <a class="page-link" href="?search=<?= urlencode($search) ?>&page=<?= $i ?>"><?= $i ?></a>
      </li>
    <?php endfor; ?>
  </ul>
</nav>

    </div>
  </div>
</div>

<?php
include 'includes/ativar.php';

include 'includes/footer.php';
include 'includes/scripts.php';
?>
<?php include 'includes/modals.php'; ?>



<script>
document.addEventListener("DOMContentLoaded", function() {
  const searchInput = document.getElementById("searchInput");
  const rows = document.querySelectorAll("tbody tr");

  searchInput.addEventListener("input", function() {
    const filter = this.value.toLowerCase();

    rows.forEach(row => {
      const usernameCell = row.querySelector("td strong");
      const username = usernameCell ? usernameCell.textContent.toLowerCase() : "";

      row.style.display = username.includes(filter) ? "" : "none";
    });
  });
});
</script>
